package com.muyu.customer.business.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.UUID;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSON;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.customer.business.domain.IndexConfiguration;
import com.muyu.customer.business.domain.MessageDetail;
import com.muyu.customer.business.domain.Vehicle;
import com.muyu.customer.business.domain.req.IndexConfigurationEditReq;
import com.muyu.customer.business.domain.req.IndexConfigurationQueryReq;
import com.muyu.customer.business.domain.req.IndexConfigurationSaveReq;
import com.muyu.customer.business.mapper.MessageDetailMapper;
import com.muyu.customer.business.mapper.VehicleMapper;
import com.muyu.customer.business.service.IndexConfigurationService;
import com.muyu.customer.business.service.MessageDetailService;
import com.muyu.customer.business.service.VehicleService;
import io.swagger.annotations.*;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 车辆指标预警配置Controller
 *
 * @author muyu
 * @date 2024-06-28
 */
@Api(tags = "车辆指标预警配置")
@RestController
@Log4j2
@RequestMapping("/indexConfiguration")
public class IndexConfigurationController extends BaseController {
    @Autowired
    private IndexConfigurationService indexConfigurationService;

//    @Autowired
//    private VehicleMapper vehicleMapper;
    @Autowired
    private MessageDetailMapper messageDetailMapper;

    @Autowired
    private RabbitTemplate rabbitTemplate;

    @Autowired
    private StringRedisTemplate redisTemplate;
    /**
     * 查询车辆指标预警配置列表
     */
    @ApiOperation("获取车辆指标预警配置列表")
    @GetMapping("/list")
    public Result<TableDataInfo<IndexConfiguration>> list(IndexConfigurationQueryReq indexConfigurationQueryReq) {
        startPage();
        List<IndexConfiguration> list = indexConfigurationService.list(IndexConfiguration.queryBuild(indexConfigurationQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出车辆指标预警配置列表
     */
    @RequiresPermissions("customerBusiness:indexConfiguration:list")
    @ApiOperation("导出车辆指标预警配置列表")
    @Log(title = "车辆指标预警配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, IndexConfiguration indexConfiguration) {
        List<IndexConfiguration> list = indexConfigurationService.list(indexConfiguration);
        ExcelUtil<IndexConfiguration> util = new ExcelUtil<IndexConfiguration>(IndexConfiguration.class);
        util.exportExcel(response, list, "车辆指标预警配置数据");
    }

    /**
     * 获取车辆指标预警配置详细信息
     */
    @ApiOperation("获取车辆指标预警配置详细信息")
    @RequiresPermissions("customerBusiness:indexConfiguration:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<IndexConfiguration> getInfo(@PathVariable("id") Long id) {
        return Result.success(indexConfigurationService.getById(id));
    }

    /**
     * 新增车辆指标预警配置
     */
    @RequiresPermissions("customerBusiness:indexConfiguration:add")
    @Log(title = "车辆指标预警配置", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增车辆指标预警配置")
    public Result<String> add(@RequestBody IndexConfigurationSaveReq indexConfigurationSaveReq) {

        indexConfigurationSaveReq.setOpportunity(indexConfigurationSaveReq.getIntervalRange()/indexConfigurationSaveReq.getOpportunity());
        boolean save = indexConfigurationService.save(IndexConfiguration.saveBuild(indexConfigurationSaveReq));
        redis(indexConfigurationSaveReq);
        return toAjax(save);
    }

    /**
     * 修改车辆指标预警配置
     */
    @RequiresPermissions("customerBusiness:indexConfiguration:edit")
    @Log(title = "车辆指标预警配置", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改车辆指标预警配置")
    public Result<String> edit(@PathVariable Long id, @RequestBody IndexConfigurationEditReq indexConfigurationEditReq) {
        indexConfigurationEditReq.setOpportunity(indexConfigurationEditReq.getIntervalRange()/indexConfigurationEditReq.getOpportunity());
        boolean update = indexConfigurationService.updateById(IndexConfiguration.editBuild(id, indexConfigurationEditReq));
//        redis(indexConfigurationEditReq);
        return toAjax(update);
    }

    /**
     * 删除车辆指标预警配置
     */
    @RequiresPermissions("customerBusiness:indexConfiguration:remove")
    @Log(title = "车辆指标预警配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除车辆指标预警配置")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(indexConfigurationService.removeBatchByIds(ids));
    }



    private void redis(IndexConfigurationSaveReq indexConfigurationSaveReq) {
        List<IndexConfiguration> list = indexConfigurationService.selectByVin(indexConfigurationSaveReq.getVin());
//        list.add(IndexConfiguration.saveBuild(indexConfigurationSaveReq));
//        list.stream().distinct();
        redisTemplate.opsForHash().put("indexConfiguration", indexConfigurationSaveReq.getVin(), JSON.toJSONString(list));
    }
}
