package com.muyu.customer.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.customer.business.domain.model.MessageDetailModel;
import com.muyu.customer.business.domain.req.MessageDetailEditReq;
import com.muyu.customer.business.domain.req.MessageDetailQueryReq;
import com.muyu.customer.business.domain.req.MessageDetailSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.customer.business.domain.MessageDetail;
import com.muyu.customer.business.service.MessageDetailService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 报文详情Controller
 *
 * @author muyu
 * @date 2024-06-28
 */
@Api(tags = "报文详情")
@RestController
@RequestMapping("/detail")
public class MessageDetailController extends BaseController {
    @Autowired
    private MessageDetailService messageDetailService;

    /**
     * 查询报文详情列表
     */
    @ApiOperation("获取报文详情列表")
    @RequiresPermissions("customerBusiness:detail:list")
    @GetMapping("/list")
    public Result<TableDataInfo<MessageDetail>> list(MessageDetailQueryReq messageDetailQueryReq) {
        startPage();
        List<MessageDetail> list = messageDetailService.list(MessageDetail.queryBuild(messageDetailQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出报文详情列表
     */
    @ApiOperation("导出报文详情列表")
    @RequiresPermissions("customerBusiness:detail:export")
    @Log(title = "报文详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MessageDetail messageDetail) {
        List<MessageDetail> list = messageDetailService.list(messageDetail);
        ExcelUtil<MessageDetail> util = new ExcelUtil<MessageDetail>(MessageDetail.class);
        util.exportExcel(response, list, "报文详情数据");
    }

    @GetMapping("/selectByVin/{vin}")
    public Result<List<MessageDetail>> selectByVin(@PathVariable String vin) {
        return Result.success(messageDetailService.selectMessage(vin));
    }

    /**
     * 获取报文详情详细信息
     */
    @ApiOperation("获取报文详情详细信息")
    @RequiresPermissions("customerBusiness:detail:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<MessageDetail> getInfo(@PathVariable("id") Long id) {
        return Result.success(messageDetailService.getById(id));
    }

    /**
     * 新增报文详情
     */
    @RequiresPermissions("customerBusiness:detail:add")
    @Log(title = "报文详情", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增报文详情")
    public Result<String> add(@RequestBody MessageDetailModel messageDetailModel) {
        return messageDetailService.add(messageDetailModel);
    }

    /**
     * 修改报文详情
     */
    @RequiresPermissions("customerBusiness:detail:edit")
    @Log(title = "报文详情", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改报文详情")
    public Result<String> edit(@PathVariable Long id, @RequestBody MessageDetailEditReq messageDetailEditReq) {
        return toAjax(messageDetailService.updateById(MessageDetail.editBuild(id,messageDetailEditReq)));
    }

    @PostMapping("/updateMessage")
    public Result<String> updateMessage(@RequestBody MessageDetailModel messageDetailModel) {
        return messageDetailService.updateVehicle(messageDetailModel);
    }

    /**
     * 删除报文详情
     */
    @RequiresPermissions("customerBusiness:detail:remove")
    @Log(title = "报文详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除报文详情")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(messageDetailService.removeBatchByIds(ids));
    }
}
